@@ -4,20 +4,9 @@
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 #
 # Modified by Anders Logg, 2008-2009.
 
@@ -27,9 +16,8 @@
 #        recommended to use. The __all__ list below is a start based
 #        on grepping of other FEniCS code for ufl.algorithm imports.
 
-from ufl.utils.str import as_native_strings
 
-__all__ = as_native_strings([
+__all__ = [
     "estimate_total_polynomial_degree",
     "sort_elements",
     "compute_form_data",
@@ -49,6 +37,8 @@ __all__ = as_native_strings([
     "expand_derivatives",
     "extract_coefficients",
     "strip_variables",
+    "strip_terminal_data",
+    "replace_terminal_data",
     "post_traversal",
     "change_to_reference_grad",
     "expand_compounds",
@@ -63,7 +53,7 @@ __all__ = as_native_strings([
     "compute_form_functional",
     "compute_form_signature",
     "tree_format",
-])
+]
 
 # Utilities for traversing over expression trees in different ways
 # from ufl.algorithms.traversal import iter_expressions
@@ -105,6 +95,8 @@ from ufl.algorithms.transformer import Transformer, ReuseTransformer
 # from ufl.algorithms.transformer import is_post_handler
 from ufl.algorithms.transformer import apply_transformer
 from ufl.algorithms.transformer import strip_variables
+from ufl.algorithms.strip_terminal_data import strip_terminal_data
+from ufl.algorithms.strip_terminal_data import replace_terminal_data
 # from ufl.algorithms.replace import Replacer
 from ufl.algorithms.replace import replace
 from ufl.algorithms.change_to_reference import change_to_reference_grad
