@@ -8,20 +8,9 @@ of classes, and for mapping types to different handler functions."""
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 #
 # Modified by Anders Logg, 2009.
 # Modified by Kristian B. Oelgaard, 2011
@@ -30,7 +19,6 @@ of classes, and for mapping types to different handler functions."""
 # This will be populated part by part below
 __all__ = []
 
-from ufl.utils.py23 import as_native_strings
 
 # Import all submodules, triggering execution of the ufl_type class
 # decorator for each Expr class.
@@ -47,6 +35,7 @@ import ufl.coefficient
 import ufl.geometry
 
 # Operator types
+import ufl.averaging
 import ufl.indexed
 import ufl.indexsum
 import ufl.variable
@@ -135,6 +124,3 @@ __all__ += populate_namespace_with_module_classes(ufl.form, locals())
 
 import ufl.equation  # noqa E401
 __all__ += populate_namespace_with_module_classes(ufl.equation, locals())
-
-
-__all__ = as_native_strings(__all__)
