@@ -3,22 +3,10 @@
 
 # Copyright (C) 2014 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 
-from ufl.utils.str import as_native_str
 from ufl.log import error
 from ufl.core.expr import Expr
 from ufl.core.operator import Operator
@@ -51,7 +39,7 @@ class ExprList(Operator):
 
     def __repr__(self):
         r = "ExprList(*%s)" % repr(self.ufl_operands)
-        return as_native_str(r)
+        return r
 
     @property
     def ufl_shape(self):
@@ -104,7 +92,7 @@ class ExprMapping(Operator):
 
     def __repr__(self):
         r = "ExprMapping(*%s)" % repr(self.ufl_operands)
-        return as_native_str(r)
+        return r
 
     @property
     def ufl_shape(self):
