@@ -3,20 +3,9 @@
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 #
 # Modified by Kristian B. Oelgaard
 # Modified by Marie E. Rognes 2010, 2012
@@ -24,8 +13,6 @@
 # Modified by Massimiliano Leoni, 2016
 
 from ufl.log import error
-from ufl.utils.str import as_native_str
-from ufl.utils.str import as_native_strings
 from ufl.utils.formatting import istr
 from ufl.cell import as_cell
 
@@ -37,10 +24,10 @@ from ufl.finiteelement.finiteelementbase import FiniteElementBase
 class FiniteElement(FiniteElementBase):
     "The basic finite element class for all simple finite elements."
     # TODO: Move these to base?
-    __slots__ = as_native_strings(("_short_name",
-                                   "_sobolev_space",
-                                   "_mapping",
-                                   "_variant"))
+    __slots__ = ("_short_name",
+                 "_sobolev_space",
+                 "_mapping",
+                 "_variant")
 
     def __new__(cls,
                 family,
@@ -125,6 +112,13 @@ class FiniteElement(FiniteElementBase):
                                               for c in cell.sub_cells()],
                                             cell=cell)
 
+            elif family == "DQ L2":
+                def dq_family_l2(cell):
+                    return "DG L2" if cell.cellname() in simplices else "DQ L2"
+                return TensorProductElement(*[FiniteElement(dq_family_l2(c), c, degree, variant=variant)
+                                              for c in cell.sub_cells()],
+                                            cell=cell)
+
         return super(FiniteElement, cls).__new__(cls)
 
     def __init__(self,
@@ -190,8 +184,8 @@ class FiniteElement(FiniteElementBase):
             var_str = ""
         else:
             var_str = ", variant=%s" % repr(v)
-        self._repr = as_native_str("FiniteElement(%s, %s, %s%s%s)" % (
-            repr(self.family()), repr(self.cell()), repr(self.degree()), quad_str, var_str))
+        self._repr = "FiniteElement(%s, %s, %s%s%s)" % (
+            repr(self.family()), repr(self.cell()), repr(self.degree()), quad_str, var_str)
         assert '"' not in self._repr
 
     def mapping(self):
@@ -202,9 +196,10 @@ class FiniteElement(FiniteElementBase):
         return self._sobolev_space
 
     def variant(self):
+        """Return the variant used to initialise the element."""
         return self._variant
 
-    def reconstruct(self, family=None, cell=None, degree=None):
+    def reconstruct(self, family=None, cell=None, degree=None, quad_scheme=None, variant=None):
         """Construct a new FiniteElement object with some properties
         replaced with new values."""
         if family is None:
@@ -213,7 +208,11 @@ class FiniteElement(FiniteElementBase):
             cell = self.cell()
         if degree is None:
             degree = self.degree()
-        return FiniteElement(family, cell, degree, quad_scheme=self.quadrature_scheme(), variant=self.variant())
+        if quad_scheme is None:
+            quad_scheme = self.quadrature_scheme()
+        if variant is None:
+            variant = self.variant()
+        return FiniteElement(family, cell, degree, quad_scheme=quad_scheme, variant=variant)
 
     def __str__(self):
         "Format as string for pretty printing."
