@@ -3,20 +3,9 @@
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 #
 # Modified by Kristian B. Oelgaard
 # Modified by Marie E. Rognes 2010, 2012
@@ -25,7 +14,6 @@
 from itertools import chain
 
 from ufl.log import error
-from ufl.utils.str import as_native_strings
 from ufl.cell import TensorProductCell, as_cell
 from ufl.sobolevspace import DirectionalSobolevSpace
 
@@ -41,7 +29,7 @@ class TensorProductElement(FiniteElementBase):
     :math:`\{ \phi_{j_1} \otimes \phi_{j_2} \otimes \cdots \otimes \phi_{j_d}
     \}` forms a basis for :math:`V`.
     """
-    __slots__ = as_native_strings(("_sub_elements", "_cell"))
+    __slots__ = ("_sub_elements", "_cell")
 
     def __init__(self, *elements, **kwargs):
         "Create TensorProductElement from a given list of elements."
@@ -86,6 +74,8 @@ class TensorProductElement(FiniteElementBase):
     def mapping(self):
         if all(e.mapping() == "identity" for e in self._sub_elements):
             return "identity"
+        elif all(e.mapping() == "L2 Piola" for e in self._sub_elements):
+            return "L2 Piola"
         else:
             return "undefined"
 
@@ -113,8 +103,9 @@ class TensorProductElement(FiniteElementBase):
         "Return subelements (factors)."
         return self._sub_elements
 
-    def reconstruct(self, cell=None):
-        return TensorProductElement(*self.sub_elements(), cell=cell)
+    def reconstruct(self, **kwargs):
+        cell = kwargs.pop("cell", self.cell())
+        return TensorProductElement(*[e.reconstruct(**kwargs) for e in self.sub_elements()], cell=cell)
 
     def __str__(self):
         "Pretty-print."
