@@ -3,23 +3,13 @@
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 #
 # Modified by Anders Logg, 2009-2011.
 # Modified by Massimiliano Leoni, 2016.
+# Modified by Cecile Daversin-Catty, 2018.
 
 from itertools import chain
 from collections import defaultdict
@@ -32,10 +22,9 @@ from ufl.equation import Equation
 from ufl.core.expr import Expr
 from ufl.core.expr import ufl_err_str
 from ufl.constantvalue import Zero
-from ufl.utils.str import as_native_strings, as_native_str
 
 # Export list for ufl.classes
-__all_classes__ = as_native_strings(["Form"])
+__all_classes__ = ["Form"]
 
 # --- The Form class, representing a complete variational form or functional ---
 
@@ -92,6 +81,8 @@ class Form(object):
         "_arguments",
         "_coefficients",
         "_coefficient_numbering",
+        "_constant_numbering",
+        "_constants",
         "_hash",
         "_signature",
         # --- Dict that external frameworks can place framework-specific
@@ -121,6 +112,12 @@ class Form(object):
         self._arguments = None
         self._coefficients = None
         self._coefficient_numbering = None
+        self._constant_numbering = None
+
+        from ufl.algorithms.analysis import extract_constants
+        self._constants = extract_constants(self)
+        self._constant_numbering = dict(
+            (c, i) for i, c in enumerate(self._constants))
 
         # Internal variables for caching of hash and signature after
         # first request
@@ -141,6 +138,11 @@ class Form(object):
         return tuple(integral for integral in self.integrals()
                      if integral.integral_type() == integral_type)
 
+    def integrals_by_domain(self, domain):
+        "Return a sequence of all integrals with a particular integration domain."
+        return tuple(integral for integral in self.integrals()
+                     if integral.ufl_domain() == domain)
+
     def empty(self):
         "Returns whether the form has no integrals."
         return self.integrals() == ()
@@ -182,6 +184,7 @@ class Form(object):
             error(
                 "Calling Form.ufl_domain() is only valid if all integrals share domain."
             )
+
         # Return the one and only domain
         return domains[0]
 
@@ -235,6 +238,14 @@ class Form(object):
             self._analyze_form_arguments()
         return self._coefficient_numbering
 
+    def constants(self):
+        return self._constants
+
+    def constant_numbering(self):
+        """Return a contiguous numbering of constants in a mapping
+        ``{constant:number}``."""
+        return self._constant_numbering
+
     def signature(self):
         "Signature for use with jit cache (independent of incidental numbering of indices etc.)"
         if self._signature is None:
@@ -336,7 +347,7 @@ class Form(object):
         to replace Coefficients with expressions of matching shapes.
 
         Example:
-
+        -------
           V = FiniteElement("CG", triangle, 1)
           v = TestFunction(V)
           u = TrialFunction(V)
@@ -394,7 +405,7 @@ class Form(object):
         # Not caching this because it can be huge
         itgs = ", ".join(repr(itg) for itg in self.integrals())
         r = "Form([" + itgs + "])"
-        return as_native_str(r)
+        return r
 
     # --- Analysis functions, precomputation and caching of various quantities
 
@@ -456,9 +467,11 @@ class Form(object):
         # Include integration domains and coefficients in renumbering
         dn = self.domain_numbering()
         cn = self.coefficient_numbering()
+        cnstn = self.constant_numbering()
         renumbering = {}
         renumbering.update(dn)
         renumbering.update(cn)
+        renumbering.update(cnstn)
 
         # Add domains of coefficients, these may include domains not
         # among integration domains
@@ -469,6 +482,22 @@ class Form(object):
                 renumbering[d] = k
                 k += 1
 
+        # Add domains of arguments, these may include domains not
+        # among integration domains
+        for a in self._arguments:
+            d = a.ufl_function_space().ufl_domain()
+            if d is not None and d not in renumbering:
+                renumbering[d] = k
+                k += 1
+
+        # Add domains of constants, these may include domains not
+        # among integration domains
+        for c in self._constants:
+            d = c.ufl_domain()
+            if d is not None and d not in renumbering:
+                renumbering[d] = k
+                k += 1
+
         return renumbering
 
     def _compute_signature(self):
@@ -477,6 +506,13 @@ class Form(object):
                                                  self._compute_renumbering())
 
 
+def sub_forms_by_domain(form):
+    "Return a list of forms each with an integration domain"
+    if not isinstance(form, Form):
+        error("Unable to convert object to a UFL form: %s" % ufl_err_str(form))
+    return [Form(form.integrals_by_domain(domain)) for domain in form.ufl_domains()]
+
+
 def as_form(form):
     "Convert to form if not a form, otherwise return form."
     if not isinstance(form, Form):
