@@ -440,7 +440,7 @@ class Expression2UnicodeHandler(MultiFunction):
                 var += UC.combining_right_arrow_above
             elif len(o.ufl_shape) > 1 and self.colorama_bold:
                 var = "%s%s%s" % (colorama.Style.BRIGHT, var, colorama.Style.RESET_ALL)
-            return "%s%s" % (var, superscript_number(i))
+            return "%s%s" % (var, subscript_number(i))
         return self.coefficient_names[o.count()]
 
     def constant(self, o):
@@ -544,7 +544,7 @@ class Expression2UnicodeHandler(MultiFunction):
         return "%s%s%s%s%s" % (UC.nabla, UC.thin_space, UC.cross_product, UC.thin_space, f)
 
     def math_function(self, o, f):
-        op = opfont(self._name)
+        op = opfont(o._name)
         f = par(f)
         return "%s%s" % (op, f)
 
