@@ -3,24 +3,11 @@
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 
-from six.moves import zip
 from ufl.log import error
-from ufl.utils.py23 import as_native_strings
 from ufl.constantvalue import Zero
 from ufl.core.expr import Expr, ufl_err_str
 from ufl.core.ufl_type import ufl_type
@@ -34,10 +21,10 @@ from ufl.precedence import parstr
 
 @ufl_type(is_shaping=True, num_ops=2, is_terminal_modifier=True)
 class Indexed(Operator):
-    __slots__ = as_native_strings((
+    __slots__ = (
         "ufl_free_indices",
         "ufl_index_dimensions",
-    ))
+    )
 
     def __new__(cls, expression, multiindex):
         if isinstance(expression, Zero):
@@ -55,6 +42,8 @@ class Indexed(Operator):
             else:
                 fi, fid = (), ()
             return Zero(shape=(), free_indices=fi, index_dimensions=fid)
+        elif expression.ufl_shape == () and multiindex == ():
+            return expression
         else:
             return Operator.__new__(cls)
 
@@ -75,7 +64,7 @@ class Indexed(Operator):
             error("Invalid number of indices (%d) for tensor "
                   "expression of rank %d:\n\t%s\n"
                   % (len(multiindex), len(expression.ufl_shape), ufl_err_str(expression)))
-        if any(int(di) >= int(si)
+        if any(int(di) >= int(si) or int(di) < 0
                for si, di in zip(shape, multiindex)
                if isinstance(di, FixedIndex)):
             error("Fixed index out of range!")
@@ -122,4 +111,8 @@ class Indexed(Operator):
                            self.ufl_operands[1])
 
     def __getitem__(self, key):
+        if key == ():
+            # So that one doesn't have to special case indexing of
+            # expressions without shape.
+            return self
         error("Attempting to index with %s, but object is already indexed: %s" % (ufl_err_str(key), ufl_err_str(self)))
