@@ -1,26 +1,15 @@
 # -*- coding: utf-8 -*-
-"Various dict manipulation utilities."
+"""Various dict manipulation utilities."""
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 
 
 def split_dict(d, criteria):
-    "Split a dict d into two dicts based on a criteria on the keys."
+    """Split a dict d into two dicts based on a criteria on the keys."""
     a = {}
     b = {}
     for (k, v) in d.items():
@@ -36,7 +25,7 @@ def slice_dict(dictionary, keys, default=None):
 
 
 def some_key(a_dict):
-    "Return an arbitrary key from a dictionary."
+    """Return an arbitrary key from a dictionary."""
     return next(a_dict.keys())
 
 
@@ -58,7 +47,7 @@ def subdict(superdict, keys):
 
 
 def dict_sum(items):
-    "Construct a dict, in between dict(items) and sum(items), by accumulating items for each key."
+    """Construct a dict, in between dict(items) and sum(items), by accumulating items for each key."""
     d = {}
     for k, v in items:
         if k not in d:
