@@ -1,29 +1,18 @@
 # -*- coding: utf-8 -*-
-"Various sequence manipulation utilities."
+"""Various sequence manipulation utilities."""
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 
 from functools import reduce
 import numpy
 
 
 def product(sequence):
-    "Return the product of all elements in a sequence."
+    """Return the product of all elements in a sequence."""
     p = 1
     for f in sequence:
         p *= f
@@ -31,7 +20,9 @@ def product(sequence):
 
 
 def unzip(seq):
-    "Inverse operation of zip: unzip(zip(a, b)) == (a, b)"
+    """Inverse operation of zip:
+
+    unzip(zip(a, b)) == (a, b)."""
     return [s[0] for s in seq], [s[1] for s in seq]
 
 
@@ -40,12 +31,12 @@ def xor(a, b):
 
 
 def or_tuples(seqa, seqb):
-    "Return 'or' of all pairs in two sequences of same length."
+    """Return 'or' of all pairs in two sequences of same length."""
     return tuple(a or b for (a, b) in zip(seqa, seqb))
 
 
 def and_tuples(seqa, seqb):
-    "Return 'and' of all pairs in two sequences of same length."
+    """Return 'and' of all pairs in two sequences of same length."""
     return tuple(a and b for (a, b) in zip(seqa, seqb))
 
 
